/*
 * Copyright (C) 2004-2010
 *           Brian Goetz <brian@quiotix.com>
 *           Loic Dachary <loic@dachary.org>
 *
 * This program gives you software freedom; you can copy, convey,
 * propagate, redistribute and/or modify this program under the terms of
 * the GNU General Public License (GPL) as published by the Free Software
 * Foundation (FSF), either version 3 of the License, or (at your option)
 * any later version of the GPL published by the FSF.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program in a file in the toplevel directory called "GPLv3".
 * If not, see <http://www.gnu.org/licenses/>.
 */
#undef Deck_N_CARDS      
#undef Deck_MASK         
#undef Deck_RANK         
#undef Deck_SUIT         

#undef Rank_2            
#undef Rank_3            
#undef Rank_4            
#undef Rank_5            
#undef Rank_6            
#undef Rank_7            
#undef Rank_8            
#undef Rank_9            
#undef Rank_TEN          
#undef Rank_JACK         
#undef Rank_QUEEN        
#undef Rank_KING         
#undef Rank_ACE          
#undef Rank_FIRST        
#undef Rank_COUNT        

#undef Suit_HEARTS       
#undef Suit_DIAMONDS     
#undef Suit_CLUBS        
#undef Suit_SPADES       
#undef Suit_FIRST        
#undef Suit_COUNT        

#undef CardMask               
#undef CardMask_OR            
#undef CardMask_SET           
#undef CardMask_CARD_IS_SET   
#undef CardMask_ANY_SET       
#undef CardMask_RESET         
#undef CardMask_NOT
#undef CardMask_XOR
#undef CardMask_AND
#undef CardMask_UNSET

#undef CardMask_SPADES        
#undef CardMask_HEARTS        
#undef CardMask_CLUBS         
#undef CardMask_DIAMONDS      
#undef CardMask_SET_SPADES        
#undef CardMask_SET_HEARTS        
#undef CardMask_SET_CLUBS         
#undef CardMask_SET_DIAMONDS      

#undef Deck_cardToString
#undef Deck_maskToString
#undef Deck_printCard
#undef Deck_printMask

#undef CurDeck
